Block

Struct Block 

pub struct Block<'a> { /* private fields */ }
Base widget to be used with all upper level ones. It may be used to display a box border around the widget and/or add a title.

Examples

Block::default()
    .title("Block")
    .title_style(Style::default().fg(Color::Red))
    .borders(Borders::LEFT | Borders::RIGHT)
    .border_style(Style::default().fg(Color::White))
    .border_type(BorderType::Rounded)
    .style(Style::default().bg(Color::Black));

Implementations

Source

impl<'a> Block<'a>

pub fn title(self, title: &'a str) -> Block<'a>

pub fn title_style(self, style: Style) -> Block<'a>

pub fn border_style(self, style: Style) -> Block<'a>

pub fn style(self, style: Style) -> Block<'a>

pub fn borders(self, flag: Borders) -> Block<'a>

pub fn border_type(self, border_type: BorderType) -> Block<'a>

pub fn inner(&self, area: Rect) -> Rect

Compute the inner area of a block based on its border visibility rules.