pub struct Chart<'a, LX, LY>{ /* private fields */ }Expand description
A widget to plot one or more dataset in a cartesian coordinate system
Examples
Chart::default()
.block(Block::default().title("Chart"))
.x_axis(Axis::default()
.title("X Axis")
.title_style(Style::default().fg(Color::Red))
.style(Style::default().fg(Color::White))
.bounds([0.0, 10.0])
.labels(&["0.0", "5.0", "10.0"]))
.y_axis(Axis::default()
.title("Y Axis")
.title_style(Style::default().fg(Color::Red))
.style(Style::default().fg(Color::White))
.bounds([0.0, 10.0])
.labels(&["0.0", "5.0", "10.0"]))
.datasets(&[Dataset::default()
.name("data1")
.marker(Marker::Dot)
.graph_type(GraphType::Scatter)
.style(Style::default().fg(Color::Cyan))
.data(&[(0.0, 5.0), (1.0, 6.0), (1.5, 6.434)]),
Dataset::default()
.name("data2")
.marker(Marker::Braille)
.graph_type(GraphType::Line)
.style(Style::default().fg(Color::Magenta))
.data(&[(4.0, 5.0), (5.0, 8.0), (7.66, 13.5)])]);Implementations
Sourceimpl<'a, LX, LY> Chart<'a, LX, LY>
impl<'a, LX, LY> Chart<'a, LX, LY>
pub fn block(self, block: Block<'a>) -> Chart<'a, LX, LY>
pub fn style(self, style: Style) -> Chart<'a, LX, LY>
pub fn x_axis(self, axis: Axis<'a, LX>) -> Chart<'a, LX, LY>
pub fn y_axis(self, axis: Axis<'a, LY>) -> Chart<'a, LX, LY>
pub fn datasets(self, datasets: &'a [Dataset<'a>]) -> Chart<'a, LX, LY>
Set the constraints used to determine whether the legend should be shown or not.
Examples
let constraints = (
Constraint::Ratio(1, 3),
Constraint::Ratio(1, 4)
);
// Hide the legend when either its width is greater than 33% of the total widget width
// or if its height is greater than 25% of the total widget height.
let _chart: Chart<String, String> = Chart::default()
.hidden_legend_constraints(constraints);Trait Implementations